package cn.fw.morax.domain.db.kpi;

import cn.fw.common.data.entity.BaseAuditableEntity;
import cn.fw.common.data.mybatis.handler.LongListTypeHandler;
import cn.fw.common.data.mybatis.handler.StringListTypeHandler;
import cn.fw.morax.domain.enums.SettingStatusEnum;
import cn.fw.morax.domain.enums.StarEvaluationEnum;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.datatype.jsr310.deser.LocalDateDeserializer;
import com.fasterxml.jackson.datatype.jsr310.ser.LocalDateSerializer;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.List;

/**
 * @author : kurisu
 * @date : 2022-4-6
 * @desc : 绩效组配置
 */
@Data
@TableName(autoResultMap = true)
@EqualsAndHashCode(callSuper = true)
public class KpiGroup extends BaseAuditableEntity<KpiGroup, Long> {
    /**
     * 名称
     */
    private String name;
    /**
     * 绩效组编码
     */
    private String kgc;
    /**
     * 岗位id
     */
    private Long postId;
    /**
     * 岗位名称
     */
    private String postName;
    /**
     * 适用门店ids
     */
    @TableField(typeHandler = LongListTypeHandler.class)
    private List<Long> shopIds;
    /**
     * 适用门店名称
     */
    @TableField(typeHandler = StringListTypeHandler.class)
    private List<String> shopNames;
    /**
     * 前一次配置id
     */
    private Long preId;
    /**
     * 生效时间
     */
    @JsonDeserialize(using = LocalDateDeserializer.class)
    @JsonSerialize(using = LocalDateSerializer.class)
    private LocalDate beginTime;
    /**
     * 失效时间
     */
    @JsonDeserialize(using = LocalDateDeserializer.class)
    @JsonSerialize(using = LocalDateSerializer.class)
    private LocalDate overTime;
    /**
     * 调整原因
     */
    private String reason;
    /**
     * 附件;fid逗号隔开
     */
    @TableField(typeHandler = StringListTypeHandler.class)
    private List<String> attachment;
    /**
     * 状态;1:审批中 2:待生效 3:生效中 4:已失效
     */
    private SettingStatusEnum status;
    /**
     * 包含指标数量
     */
    private Integer indicatorNum;
    /**
     * 星级评定方式;1:绩效得分率 2:人员百分比
     */
    private StarEvaluationEnum starEvaluationType;
    /**
     * 撤销D级得分率
     */
    private BigDecimal revokedScoreRatio;
    /**
     * 集团id
     */
    private Long groupId;
    /**
     * 逻辑删除
     */
    @TableLogic
    private Boolean yn;

}