package cn.fw.morax.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * 适用角色类型枚举
 *
 * @author kurisu
 */
public enum ApplicableRoleEnum implements IEnum<Integer> {
    /**
     * 全部角色
     */
    ALL(1, "全部角色"),
    /**
     * 全部管理角色
     */
    MANAGEMENT_ROLE(2, "全部管理角色"),
    /**
     * 自定义角色
     */
    PORTION(3, "自定义角色"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    ApplicableRoleEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static ApplicableRoleEnum ofValue(final Integer value) {
        for (final ApplicableRoleEnum _enum : ApplicableRoleEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final ApplicableRoleEnum _enum : ApplicableRoleEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum.getName();
            }
        }
        return "";
    }
}
