package cn.fw.morax.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : ApprovalStatusEnum
 * @description : 审批状态枚举
 * @date: 2022-04-06 14:20
 */
public enum ApprovalStatusEnum implements IEnum<Integer> {
    /**
     * 审批状态;1:审批中 2:审批通过 3:审批拒绝
     */
    IN_APPROVAL(1, "审批中"),
    PASS(2, "审批通过"),
    REFUSE(3, "审批拒绝"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    ApprovalStatusEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static ApprovalStatusEnum ofValue(final Integer value) {
        for (final ApprovalStatusEnum _enum : ApprovalStatusEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final ApprovalStatusEnum _enum : ApprovalStatusEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}