package cn.fw.morax.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @version : 1.0
 * @className : ExtraSalaryTypeEnum
 * @description : 额外薪酬项目类型
 * @date : 2022-04-24 15:25
 */
public enum ExtraSalaryTypeEnum implements IEnum<Integer> {
    /**
     * 额外薪酬项目类型
     */
    AWARD(1, "奖励"),
    PENALTY(2, "处罚"),
    NECESSARY(3, "社保扣款"),
    SUBSIDY(4, "福利补贴"),
    PERSON_TAX(5, "个税"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    ExtraSalaryTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static ExtraSalaryTypeEnum ofValue(final Integer value) {
        for (final ExtraSalaryTypeEnum _enum : ExtraSalaryTypeEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final ExtraSalaryTypeEnum _enum : ExtraSalaryTypeEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}
