package cn.fw.morax.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : SalaryConfirmStatusEnum
 * @description : 薪酬确认枚举
 * @date: 2022-04-06 14:13
 */
public enum SalaryConfirmStatusEnum implements IEnum<Integer> {
    /**
     * 确认状态;1:待定 2:已确认 3:已取消
     */
    NEED_CONFIRM(1, "待确认"),
    CONFIRMED(2, "已确认"),
    CANCELED(3, "已取消"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    SalaryConfirmStatusEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static SalaryConfirmStatusEnum ofValue(final Integer value) {
        for (final SalaryConfirmStatusEnum _enum : SalaryConfirmStatusEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final SalaryConfirmStatusEnum _enum : SalaryConfirmStatusEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}
