package cn.fw.morax.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : SettingStatusEnum
 * @description : 配置状态枚举
 * @date: 2022-04-06 10:41
 */
public enum SettingStatusEnum implements IEnum<Integer> {
    /**
     * 1:审批中 2:待生效 3:生效中 4:已失效
     */
    APPROVING(1, "审批中"),
    BE_EFFECTIVE(2, "待生效"),
    EFFECTIVE(3, "生效中"),
    INEFFECTIVE(4, "已失效"),
//    NO_PASS_APPROVING(5, "审批不通过"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    SettingStatusEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static SettingStatusEnum ofValue(final Integer value) {
        for (final SettingStatusEnum _enum : SettingStatusEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final SettingStatusEnum _enum : SettingStatusEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}
