package cn.fw.morax.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : StarEvaluationEnum
 * @description : 星级评定方式枚举
 * @date : 2022-04-06 10:48
 */
public enum StarEvaluationEnum implements IEnum<Integer> {
    /**
     * 1:绩效得分率 2:人员百分比
     */
    SCORING_RATE(1, "绩效得分率"),
    PERSONNEL_RATE(2, "人员百分比"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    StarEvaluationEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static StarEvaluationEnum ofValue(final Integer value) {
        for (final StarEvaluationEnum _enum : StarEvaluationEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final StarEvaluationEnum _enum : StarEvaluationEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}
