package cn.fw.morax.sdk.dto.kpi;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @version : 1.0
 * @className : SalaryValueEnum
 * @description : 绩效指标目标类型
 * @date : 2022-04-24 14:37
 */
public enum TargetTypeEnum {

    /**
     * 无
     */
    NO(1, "无"),
    /**
     * 百分比
     */
    RATIO(2, "百分比"),
    /**
     * 金额
     */
    MONEY(3, "金额"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    TargetTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static TargetTypeEnum ofValue(final Integer value) {
        for (final TargetTypeEnum salaryValueEnum : TargetTypeEnum.values()) {
            if (salaryValueEnum.value.equals(value)) {
                return salaryValueEnum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final TargetTypeEnum salaryValueEnum : TargetTypeEnum.values()) {
            if (salaryValueEnum.value.equals(value)) {
                return salaryValueEnum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    public Integer getValue() {
        return value;
    }
}
