package cn.fw.morax.server.consumer;


import cn.fw.ehr.sdk.api.mq.EndWaitJobEvent;
import cn.fw.ehr.sdk.api.mq.StaffPostChangeEvent;
import cn.fw.morax.common.utils.MessageFormatUtil;
import cn.fw.morax.common.utils.PublicUtil;
import cn.fw.morax.domain.db.kpi.KpiGroup;
import cn.fw.morax.domain.enums.SettingStatusEnum;
import cn.fw.morax.service.biz.kpi.KpiGroupUserBizService;
import cn.fw.morax.service.biz.kpi.KpiPoolBizService;
import cn.fw.morax.service.data.kpi.KpiGroupService;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.rocketmq.spring.annotation.RocketMQMessageListener;
import org.apache.rocketmq.spring.core.RocketMQListener;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author : jiangchao
 * Date: 2022/05/07
 * Time: 17:34
 * Description: 人事待岗结束事件
 */
@Slf4j
@RocketMQMessageListener(topic = EndWaitJobEvent.TOPIC, consumerGroup = "${spring.application.name}_" + EndWaitJobEvent.TOPIC)
@RequiredArgsConstructor
public class EhrStaffEndAwaitJobConsumer implements RocketMQListener<EndWaitJobEvent> {

    private final KpiGroupUserBizService kpiGroupUserBizService;
    private final KpiGroupService kpiGroupService;

    @Value("${spring.cache.custom.global-prefix}:kpi:anticipated_date:")
    @Getter
    private String key;

    /***
     * 人员待岗开始事件
     *
     * 1. 记录待岗开始时间
     *
     *
     * @param event
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void onMessage(EndWaitJobEvent event) {
        log.info("人事系统人员结束待岗MQ消息：{}", JSONObject.toJSONString(event));
        Long userId = event.getStaffId();

        //人员调岗完成事件
//        KpiGroup kpiGroup = kpiGroupService.getOne(Wrappers.<KpiGroup>lambdaQuery()
//                .in(KpiGroup::getPostId, event.getPostId())
//                .in(KpiGroup::getStatus, SettingStatusEnum.EFFECTIVE)
//                .apply(MessageFormatUtil.MessageFormatTransfer("FIND_IN_SET({0}, shop_ids)", event.getShopId()))
//        );
//        if (PublicUtil.isEmpty(kpiGroup)) {
//            log.info("人员待岗，目前没有匹配的绩效组，人员信息：{}", JSONObject.toJSONString(result));
//        }

        kpiGroupUserBizService.calcAwaitJobAfterStartKpiDate(userId);
    }



}


