package cn.fw.morax.server.controller.api;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.data.base.domain.common.Message;
import cn.fw.morax.sdk.api.ISalaryReportService;
import cn.fw.morax.sdk.dto.CustomList;
import cn.fw.morax.sdk.dto.kpi.KpiGroupUserQuery;
import cn.fw.morax.sdk.dto.kpi.KpiGroupUserResult;
import cn.fw.morax.sdk.dto.salary.*;
import cn.fw.morax.service.biz.salary.SalaryReportService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import java.util.List;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * 薪酬项上报类
 *
 * @author : kurisu
 * @version : 1.0
 * @className : SalaryReportServiceImpl
 * @description : 薪酬项上报类
 * @date : 2022-04-24 15:39
 */

@Slf4j
@RestController
@Validated
@RequiredArgsConstructor
@RequestMapping("/api/morax/salary")
public class SalaryReportServiceImpl implements ISalaryReportService {

    private final SalaryReportService salaryReportService;

    /**
     * 提成薪酬数据上报
     *
     * @param salaryValueList 提成薪酬数据
     */
    @PostMapping("/push-money/report")
    @Override
    @ControllerMethod("提成薪酬数据上报")
    public Message<Void> salaryReport(@Valid @RequestBody CustomList<SalaryDataReportReq> salaryValueList) {
        salaryReportService.pushMoneySalaryReport(salaryValueList);
        return success();
    }

    /**
     * 奖惩薪资
     *
     * @param salaryRewardReq 薪资项
     */
    @PostMapping("/bonus-penalty/report")
    @Override
    @ControllerMethod("奖惩薪资")
    public Message<Void> salaryRewardReport(@Valid @RequestBody SalaryRewardReq salaryRewardReq) {
        salaryReportService.salaryRewardReport(salaryRewardReq);
        return success();
    }

    /**
     * 社保扣款项上报
     *
     * @param generalSalaryProjectReq 社保扣款项
     */
    @PostMapping("/social-security/report")
    @Override
    @ControllerMethod("社保扣款项上报")
    public Message<Void> socialSecurityProject(@Valid @RequestBody GeneralSalaryProjectReq generalSalaryProjectReq) {
        salaryReportService.socialSecurityProject(generalSalaryProjectReq);
        return success();
    }

    /**
     * 福利补贴项
     *
     * @param generalSalaryProjectReq 福利补贴项
     */
    @PostMapping("/subsidy/report")
    @Override
    @ControllerMethod("福利补贴项上报")
    public Message<Void> subsidyProject(@Valid @RequestBody GeneralSalaryProjectReq generalSalaryProjectReq) {
        salaryReportService.subsidyProject(generalSalaryProjectReq);
        return success();
    }

    /**
     * 查询薪酬组人员
     *
     * @param salaryGroupUserQuery 查询参数
     * @return 分组人员
     */
    @GetMapping("/query/user")
    @Override
    @ControllerMethod("查询薪酬组人员")
    public Message<List<SalaryGroupUserResult>> querySalaryGroupUser(@Validated({SalaryGroupUserQuery.Query.class}) @SpringQueryMap SalaryGroupUserQuery salaryGroupUserQuery) {
        return success(salaryReportService.querySalaryGroupUser(salaryGroupUserQuery));
    }

    /**
     * 查询集团所有薪酬组人员
     *
     * @param salaryGroupUserQuery 查询参数
     * @return 分组人员
     */
    @GetMapping("/query/group-user")
    @Override
    @ControllerMethod("查询集团所有薪酬组人员")
    public Message<SalaryGroupUserResult> queryGroupSalaryUser(@Validated({SalaryGroupUserQuery.GroupQuery.class}) @SpringQueryMap SalaryGroupUserQuery salaryGroupUserQuery) {
        return success(salaryReportService.queryGroupSalaryUser(salaryGroupUserQuery));
    }

}
