package cn.fw.morax.server.controller.erp;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.data.base.domain.common.Message;
import cn.fw.morax.common.pojo.event.KpiStarAdjustmentEvent;
import cn.fw.morax.common.utils.EventBusUtil;
import cn.fw.morax.common.utils.PublicUtil;
import cn.fw.morax.domain.bo.kpi.KpiGroupCalculableBO;
import cn.fw.morax.domain.db.kpi.KpiIndicatorHitLog;
import cn.fw.morax.domain.db.kpi.KpiPool;
import cn.fw.morax.domain.db.kpi.KpiPoolIndicatorValue;
import cn.fw.morax.domain.enums.StarLevelEnum;
import cn.fw.morax.domain.vo.kpi.KpiGroupIndicatorVO;
import cn.fw.morax.domain.vo.kpi.KpiGroupVO;
import cn.fw.morax.service.biz.kpi.*;
import cn.fw.morax.service.data.kpi.KpiGroupService;
import cn.fw.morax.service.data.kpi.KpiIndicatorHitLogService;
import cn.fw.morax.service.data.kpi.KpiPoolIndicatorValueService;
import cn.fw.morax.service.data.kpi.KpiPoolService;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.enums.AuthType;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.google.common.collect.Lists;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.YearMonth;
import java.util.List;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * @author : kurisu
 * @version : 1.0
 * @className : DebugController
 * @description : 绩效通用调试控制器
 * @date : 2022-04-11 10:45
 * @ignore
 */
@Slf4j
@RestController
@Authorization(AuthType.NONE)
@RequiredArgsConstructor
@Validated
@RequestMapping("/debug/kpi")
public class KpiDebugController {
    private final KpiReportService kpiReportService;
    private final KpiCalculateService kpiCalculateService;
    private final KpiPoolBizService kpiPoolBizService;
    private final KpiGroupService kpiGroupService;
    private final KpiGroupBizService kpiGroupBizService;
    private final KpiGroupDataService kpiGroupDataService;
    private final KpiPoolService kpiPoolService;
    private final KpiPoolIndicatorValueService kpiPoolIndicatorValueService;
    private final KpiIndicatorHitLogService kpiIndicatorHitLogService;


    @GetMapping("/indicator/start-task")
    @ControllerMethod("手动开启指标上报task")
    public Message<Void> startTask() {
        EventBusUtil.asyncPost(KpiStarAdjustmentEvent.builder()
                .userId(1L)
                .yearMonth(YearMonth.from(YearMonth.now().minusMonths(-2L)))
                .build());
        // kpiReportService.sendNotice();
        return success();
    }

    @GetMapping("/indicator/report")
    @ControllerMethod("发送指标上报mq")
    public Message<Void> sendReportIndicator(@RequestParam("indicatorCode") String indicatorCode,
                                             @RequestParam("postId") Long postId,
                                             @RequestParam("postName") String postName,
                                             @RequestParam("groupId") Long groupId,
                                             @RequestParam("reportDate") LocalDate reportDate) {
        kpiReportService.sendNotice(indicatorCode, postId, postName, groupId, reportDate);
        return success();
    }

    @GetMapping("/indicator/report-task")
    @ControllerMethod("发送指标上报mq")
    public Message<Void> sendReportIndicator() {
        kpiReportService.sendNotice();
        return success();
    }

    @GetMapping("/indicator/calc/score")
    @ControllerMethod("计算绩效得分")
    public Message<Void> calcScore(@RequestParam("kpiGroupId") Long kpiGroupId,
                                   @RequestParam("date") LocalDate localDate) {
        kpiCalculateService.calculateKpi(new KpiGroupCalculableBO(kpiGroupId, localDate));
        return success();
    }

    @GetMapping("/indicator/calc/score-rate")
    @ControllerMethod("计算绩效得分率")
    public Message<Void> calcRate(@RequestParam("kpiGroupId") Long kpiGroupId,
                                  @RequestParam("date") LocalDate localDate) {
        kpiPoolBizService.calcuScoringRate(new KpiGroupCalculableBO(kpiGroupId, localDate));
        return success();
    }

//    @GetMapping("/calc/star")
//    @ControllerMethod("计算绩效星级")
//    public Message<Void> calcLevel(@RequestParam("kpiGroupId") Long kpiGroupId,
//                                   @RequestParam("date") LocalDate localDate) {
//        kpiPoolBizService.calcuStarLevel(new KpiGroupCalculableRankBO(kpiGroupId, localDate));
//        return success();
//    }

    @GetMapping("/indicator/calc/rank")
    @ControllerMethod("计算绩效排名")
    public Message<Void> calcLevel(@RequestParam("shopId") Long shopId,
                                   @RequestParam("postId") Long postId) {
        List<KpiPool> poolList = kpiPoolService.list(Wrappers.<KpiPool>lambdaQuery()
                .eq(KpiPool::getShopId, shopId)
                .eq(KpiPool::getMonthly, YearMonth.from(YearMonth.now()))
                .eq(KpiPool::getPostId, postId)
                .eq(KpiPool::getYn, Boolean.TRUE)
        );
        kpiPoolBizService.calcRank(poolList);
        return success();
    }

//    @GetMapping("/init-kgc")
//    @ControllerMethod("初始化绩效组编码")
//    public Message<Void> initKgc() {
//        kpiGroupDataService.initKgc();
//        return success();
//    }

    /**
     * 生成绩效池相关数据
     *
     * @return 薪酬组
     * @ignoreParams user
     */
    @GetMapping("/generate/kpi-data")
    @ControllerMethod("生成绩效池相关数据")
    public Message<Void> generateKpiData(Long userId, Long groupId, String userName, Long kpiGroupId) {
        KpiGroupVO kpiGroup = kpiGroupBizService.kpiGroupDetail(kpiGroupId);
        if (PublicUtil.isEmpty(userId)) {
            userId = 760L;
            groupId = 2L;
        }
        YearMonth yearMonth = YearMonth.now();
        LocalDate localDate = LocalDate.now();
        KpiPool kpiPool = kpiPoolService.getOne(Wrappers.<KpiPool>lambdaQuery()
                        .eq(KpiPool::getKpiGroupId, kpiGroupId)
                        .eq(KpiPool::getUserId, userId)
                        .eq(KpiPool::getMonthly, yearMonth));
        if (PublicUtil.isEmpty(kpiPool)) {
            kpiPool = new KpiPool();
            kpiPool.setKpiGroupId(kpiGroupId);
            kpiPool.setUserId(userId);
            kpiPool.setUserName(userName);
            kpiPool.setPostId(kpiGroup.getPostId());
            kpiPool.setPostName(kpiGroup.getPostName());
            kpiPool.setShopId(kpiGroup.getShopIds().get(0));
            kpiPool.setShopName(kpiGroup.getShopNames().get(0));
            kpiPool.setKpiScore(new BigDecimal(20));
            kpiPool.setKpiScoreRatio(new BigDecimal(20));
            kpiPool.setStarLevel(StarLevelEnum.D);
            kpiPool.setActualStar(StarLevelEnum.D);
            kpiPool.setRevoked(Boolean.FALSE);
            kpiPool.setInclusion(Boolean.TRUE);
            kpiPool.setMonthly(yearMonth);
            kpiPool.setRegular(Boolean.FALSE);
            kpiPool.setGroupId(groupId);
            kpiPoolService.save(kpiPool);
        }
        Long kpiPoolId = kpiPool.getId();

        List<KpiPoolIndicatorValue> indicatorValues = Lists.newArrayList();
        List<KpiIndicatorHitLog> indicatorHitLogs = Lists.newArrayList();
        for (KpiGroupIndicatorVO indicatorVO : kpiGroup.getIndicators()) {
            KpiPoolIndicatorValue kpiPoolIndicatorValue = new KpiPoolIndicatorValue();
            kpiPoolIndicatorValue.setKpiPoolId(kpiPoolId);
            kpiPoolIndicatorValue.setUserId(userId);
            kpiPoolIndicatorValue.setIndicatorCode(indicatorVO.getIndicatorCode());
            kpiPoolIndicatorValue.setIndicatorValue(new BigDecimal(10));
            kpiPoolIndicatorValue.setIndicatorScore(new BigDecimal(10));
            kpiPoolIndicatorValue.setDataDate(localDate);
            kpiPoolIndicatorValue.setMqLogId(1L);
            kpiPoolIndicatorValue.setGroupId(groupId);
            indicatorValues.add(kpiPoolIndicatorValue);

            if (PublicUtil.isNotEmpty(indicatorVO.getIndicatorLadders())) {
                KpiIndicatorHitLog kpiIndicatorHitLog = new KpiIndicatorHitLog();
                kpiIndicatorHitLog.setKpiPoolId(kpiPoolId);
                kpiIndicatorHitLog.setKpiGroupIndicatorId(indicatorVO.getId());
                kpiIndicatorHitLog.setKpiGroupIndicatorLaddersId(indicatorVO.getIndicatorLadders().get(0).getId());
                kpiIndicatorHitLog.setKpiValue(new BigDecimal(10));
                kpiIndicatorHitLog.setDataDate(localDate);
                kpiIndicatorHitLog.setGroupId(groupId);
                indicatorHitLogs.add(kpiIndicatorHitLog);
            }
        }

        kpiPoolIndicatorValueService.saveBatch(indicatorValues);
        kpiIndicatorHitLogService.saveBatch(indicatorHitLogs);
        return success();
    }

}
