package cn.fw.morax.server.controller.erp;

import cn.fw.common.page.AppPage;
import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.common.web.auth.LoginAuthBean;
import cn.fw.common.web.auth.annotation.CurrentUser;
import cn.fw.data.base.domain.common.Message;
import cn.fw.morax.common.utils.PublicUtil;
import cn.fw.morax.domain.dto.SalaryGroupDTO;
import cn.fw.morax.domain.dto.query.*;
import cn.fw.morax.domain.vo.salary.*;
import cn.fw.morax.service.biz.salary.SalaryGroupBizService;
import cn.fw.morax.service.biz.salary.SalaryGroupUserBizService;
import cn.fw.morax.service.biz.salary.SalaryPoolBizService;
import cn.fw.morax.service.biz.salary.SalaryProjectBizService;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.annotation.IgnoreAuth;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.time.YearMonth;
import java.util.List;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * 薪酬确认
 *
 * @author : kurisu
 * @version : 1.0
 * @className : SalaryGroupController
 * @description : 薪酬确认
 * @date : 2022-05-12 09:27
 */
@Slf4j
@RestController
@RequiredArgsConstructor
@Authorization(AuthType.ERP)
@IgnoreAuth
@Validated
@RequestMapping("/erp/salary")
public class SalaryConfirmController {

    private final SalaryPoolBizService salaryPoolBizService;

    /**
     * 查询工资清单
     *
     * @param dto
     * @return
     */
    @GetMapping("/staffs-wages")
    @ControllerMethod("查询工资清单")
    public Message<AppPage<StaffSalaryInfoVO>> getStaffsWages(PaySalaryQueryDTO dto) {
        if (PublicUtil.isEmpty(dto.getYearMonth())) {
            dto.setYearMonth(YearMonth.now().minusMonths(1));
        }
        return success(salaryPoolBizService.getStaffsWages(dto));
    }

    /**
     * 员工薪酬excel下载
     *
     * @return
     */
    @GetMapping("/pay-wages/download")
    public void downloadStaffsSalary(@CurrentUser LoginAuthBean currentUser,
                                     @RequestParam(required = false) YearMonth yearMonth,
                                     HttpServletRequest request,
                                     HttpServletResponse response) {
        if (PublicUtil.isEmpty(yearMonth)) {
            yearMonth = YearMonth.now().minusMonths(1);
        }
        salaryPoolBizService.downloadStaffsSalary(currentUser, yearMonth, request, response);
    }

}
