package cn.fw.morax.server.controller.erp;

import cn.fw.common.exception.BusinessException;
import cn.fw.common.page.AppPage;
import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.common.web.auth.LoginAuthBean;
import cn.fw.common.web.auth.annotation.CurrentUser;
import cn.fw.data.base.domain.common.Message;
import cn.fw.morax.domain.dto.SalaryProjectAbleDTO;
import cn.fw.morax.domain.dto.SalaryProjectDTO;
import cn.fw.morax.domain.dto.query.SalaryIndicatorQueryDTO;
import cn.fw.morax.domain.vo.salary.SalaryProjectVO;
import cn.fw.morax.domain.vo.salary.StaffPersonTaxVO;
import cn.fw.morax.service.biz.salary.SalaryExtraBizService;
import cn.fw.morax.service.biz.salary.SalaryProjectBizService;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.annotation.IgnoreAuth;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.BindException;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import java.util.List;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * 薪酬指标配置
 *
 * @author jiangchao
 */
@Slf4j
@RestController
@RequiredArgsConstructor
@Authorization(AuthType.ERP)
@Validated
@RequestMapping("/erp/salary/extra")
public class SalaryExtraController {
    private final SalaryExtraBizService salaryExtraBizService;


    /**
     * 个税模板文件
     *
     * @return
     */
    @IgnoreAuth
    @GetMapping("/person-tax/template-file")
    @ControllerMethod("薪酬指标库列表")
    public Message<Void> personTaxTemplateFile(HttpServletRequest request, HttpServletResponse response) {
        salaryExtraBizService.personTaxTemplateFile(request, response);
        return success();
    }

    /**
     * 上传个税信息
     *
     * @return
     */
    @IgnoreAuth
    @PostMapping("/person-tax")
    @ControllerMethod("薪酬指标保存")
    public Message<List<StaffPersonTaxVO>> uploadPersonTax(@RequestParam("file") MultipartFile file, @CurrentUser LoginAuthBean user) {
        if (file.isEmpty()) {
            throw new BusinessException("请上传文件");
        }
        return success(salaryExtraBizService.uploadPersonTax(file, user));
    }



}
