package cn.fw.morax.server.task;

import cn.fw.morax.common.constant.TimeTaskConstant;
import cn.fw.morax.common.utils.PublicUtil;
import cn.fw.morax.domain.db.kpi.KpiStarSpecialRule;
import cn.fw.morax.domain.enums.SettingStatusEnum;
import cn.fw.morax.service.data.kpi.KpiStarSpecialRuleService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.google.common.collect.Lists;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.time.YearMonth;
import java.util.List;

/**
 * @author : jiangchao
 * @className : KpiStarSpecialRuleTask
 * @description : 星级特殊调整定时器
 * @date : 2022-06-23 15:29
 */
@Component
@Slf4j
@RequiredArgsConstructor
@ConditionalOnProperty(prefix = "task", name = "switch", havingValue = "on")
public class KpiStarSpecialRuleTask {

    private final KpiStarSpecialRuleService kpiStarSpecialRuleService;

    /**
     * 每月1号6点执行
     *
     * 1.几月开始计算绩效的星级调整 申请设置为无效
     */
    @Scheduled(cron = TimeTaskConstant.KPI_STAR_SPECIAL_RULE)
    @Transactional(rollbackFor = Exception.class)
    public void processKpiStarSpecialRule() {
        YearMonth curMonth = YearMonth.now();
        List<KpiStarSpecialRule> specialRules = kpiStarSpecialRuleService.list(Wrappers.<KpiStarSpecialRule>lambdaQuery()
                .eq(KpiStarSpecialRule::getStatus, SettingStatusEnum.EFFECTIVE)
                .eq(KpiStarSpecialRule::getYn, Boolean.TRUE)
        );
        if (PublicUtil.isEmpty(specialRules)) {
            return;
        }

        List<Long> inEffectiveRulesIds = Lists.newArrayList();
        for (KpiStarSpecialRule rule : specialRules) {
            if (PublicUtil.isNotEmpty(rule.getEarliestStartingMonthly()) && curMonth.isAfter(YearMonth.from(rule.getEarliestStartingMonthly()))) {
                inEffectiveRulesIds.add(rule.getId());
            }
        }
        if (PublicUtil.isNotEmpty(inEffectiveRulesIds)) {
            kpiStarSpecialRuleService.update(Wrappers.<KpiStarSpecialRule>lambdaUpdate()
                    .set(KpiStarSpecialRule::getStatus, SettingStatusEnum.INEFFECTIVE)
                    .in(KpiStarSpecialRule::getId, inEffectiveRulesIds)
            );
        }
    }

}
