package cn.fw.morax.service.biz.calculator.kpi;

import cn.fw.morax.common.utils.PublicUtil;
import cn.fw.morax.domain.db.kpi.KpiGroupIndicator;
import cn.fw.morax.domain.db.kpi.KpiGroupIndicatorLadders;
import cn.fw.morax.domain.db.kpi.KpiGroupUser;
import cn.fw.morax.domain.db.kpi.KpiPoolIndicatorValue;
import cn.fw.morax.domain.enums.ScoreWayEnum;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;
import java.util.Optional;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * @author : kurisu
 * @version : 1.0
 * @className : LadderCalculator
 * @description : 阶梯计算器
 * @date : 2022-04-18 11:47
 */
@Component
@Slf4j
public class LadderCalculator extends KpiAbsBaseCalculator {
    @Override
    public ScoreWayEnum getCalMethod() {
        return ScoreWayEnum.LADDER;
    }

    @Override
    public BigDecimal calculate(KpiPoolIndicatorValue indicatorValue, KpiGroupIndicator groupIndicator) {
        List<KpiGroupIndicatorLadders> stepper = kpiGroupIndicatorLaddersService.list(Wrappers.<KpiGroupIndicatorLadders>lambdaQuery()
                .eq(KpiGroupIndicatorLadders::getKpiGroupIndicatorId, groupIndicator.getId())
                .eq(KpiGroupIndicatorLadders::getYn, Boolean.TRUE)
        );
        BV.isNotEmpty(stepper, () -> "得分阶梯不能为空");
        final BigDecimal value = Optional.ofNullable(indicatorValue.getIndicatorValue()).orElse(BigDecimal.ZERO);
        KpiGroupIndicatorLadders ladder = stepper.stream()
                .filter(r -> r.getLower().compareTo(value) <= 0)
                .filter(x -> x.getUpper().compareTo(value) > 0)
                .findAny()
                .orElse(null);
        if (PublicUtil.isEmpty(ladder)) {
            return BigDecimal.ZERO;
        }
        BigDecimal baseScore = BigDecimal.valueOf(ladder.getStandardScore());
        saveHitLog(indicatorValue, groupIndicator.getId(), ladder.getId(), value);
        BigDecimal res = baseScore.multiply(value);
        if (res.compareTo(baseScore) > 0) {
            return baseScore;
        }
        return res;
    }
}
