package cn.fw.morax.service.biz.calculator.salary;

import cn.fw.morax.domain.db.salary.SalaryGroupProject;
import cn.fw.morax.domain.db.salary.SalaryGroupProjectSettin;
import cn.fw.morax.domain.db.salary.SalaryGroupUser;
import cn.fw.morax.domain.db.salary.SalaryRawData;
import cn.fw.morax.domain.enums.SalaryCalMethodEnum;
import cn.fw.morax.domain.enums.SalaryValueTypeEnum;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.List;
import java.util.Objects;
import java.util.Optional;

/**
 * @author : kurisu
 * @version : 1.0
 * @className : LadderFixedSalaryCalculator
 * @description : 阶梯(总)计算器
 * @date : 2022-04-29 14:18
 */
@Component
@Slf4j
public class LadderFixedSalaryCalculator extends SalaryBaseCalculator {
    @Override
    public BigDecimal calculate(SalaryGroupProject param1, SalaryGroupUser param2) {
        List<SalaryGroupProjectSettin> settins = queryProjectSettins(param1.getId());
        Optional<SalaryRawData> rawData = queryRawData(param2.getUserId(), param2.getDataDate(), param1.getSalaryProjectCode(), SalaryValueTypeEnum.QUANTITY);
        Optional<JSONObject> projectValue = checkRawDataAndGetDataValue(rawData, param2.getUserId(), param1.getSalaryProjectCode());
        if (! projectValue.isPresent()) {
            return BigDecimal.ZERO;
        }
        final BigDecimal dataValue = Optional.ofNullable(projectValue.get().getBigDecimal(param1.getSalaryProjectCode())).orElse(BigDecimal.ZERO);
        SalaryGroupProjectSettin settin = settins.stream().filter(r -> BigDecimal.valueOf(r.getStairMin().longValue()).compareTo(dataValue) <= 0)
                .filter(r -> BigDecimal.valueOf(r.getStairMax().longValue()).compareTo(dataValue) > 0)
                .findAny()
                .orElse(null);
        if (Objects.isNull(settin)) {
            return BigDecimal.ZERO;
        }
        BigDecimal stairValue = Optional.ofNullable(settin.getStairValue()).orElse(BigDecimal.ZERO);
        saveHitLog(param1.getSalaryProjectId(), settin.getId(), dataValue, param2);
        if (getWorkAgeCode().equalsIgnoreCase(rawData.get().getSalaryProjectCode())) {
            BigDecimal workDayProportion = calcWorkDayProportion(param2);
            return stairValue.multiply(workDayProportion).divide(BigDecimal.ONE, 2, RoundingMode.HALF_UP);
        }
        return stairValue;
    }

    @Override
    public SalaryCalMethodEnum getCalMethod() {
        return SalaryCalMethodEnum.LADDER_FIXED;
    }
}
