package cn.fw.morax.service.biz.calculator.salary;

import cn.fw.morax.domain.db.salary.SalaryGroupProject;
import cn.fw.morax.domain.db.salary.SalaryGroupProjectSettin;
import cn.fw.morax.domain.db.salary.SalaryGroupUser;
import cn.fw.morax.domain.db.salary.SalaryRawData;
import cn.fw.morax.domain.enums.SalaryCalMethodEnum;
import cn.fw.morax.domain.enums.SalaryValueTypeEnum;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Objects;
import java.util.Optional;

/**
 * @author : kurisu
 * @version : 1.0
 * @className : ScalarSalaryCalculator
 * @description : 按数量薪资计算器
 * @date : 2022-04-27 10:37
 */
@Component
@Slf4j
public class ScalarSalaryCalculator extends SalaryBaseCalculator {
    @Override
    public BigDecimal calculate(SalaryGroupProject param1, SalaryGroupUser param2) {
        SalaryGroupProjectSettin projectSettin = queryProjectSettins(param1.getId()).stream().findAny().orElse(null);
        if (Objects.isNull(projectSettin)) {
            return BigDecimal.ZERO;
        }
        Optional<JSONObject> projectValue = queryRawDataValue(param2.getUserId(), param2.getDataDate(), param1.getSalaryProjectCode(), SalaryValueTypeEnum.QUANTITY);
        if (! projectValue.isPresent()) {
            return BigDecimal.ZERO;
        }
        BigDecimal stairValue = projectSettin.getStairValue();
        BigDecimal value = Optional.ofNullable(projectValue.get().getBigDecimal(param1.getSalaryProjectCode())).orElse(BigDecimal.ZERO);
        saveHitLog(param1.getSalaryProjectId(), projectSettin.getId(), value, param2);
        return stairValue.multiply(value).divide(BigDecimal.ONE, 2, RoundingMode.HALF_UP);
    }

    @Override
    public SalaryCalMethodEnum getCalMethod() {
        return SalaryCalMethodEnum.SCALAR;
    }
}
