package cn.fw.morax.service.biz.calculator.salary;

import cn.fw.morax.common.utils.MessageFormatUtil;
import cn.fw.morax.domain.db.kpi.KpiPool;
import cn.fw.morax.domain.db.salary.SalaryGroupProject;
import cn.fw.morax.domain.db.salary.SalaryGroupProjectSettin;
import cn.fw.morax.domain.db.salary.SalaryGroupUser;
import cn.fw.morax.domain.enums.SalaryCalMethodEnum;
import cn.fw.morax.domain.enums.SalaryValueTypeEnum;
import cn.fw.morax.domain.enums.StarLevelEnum;
import cn.fw.morax.service.biz.kpi.KpiPoolCommonService;
import cn.fw.morax.service.data.kpi.KpiPoolService;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.time.YearMonth;
import java.util.List;
import java.util.Objects;
import java.util.Optional;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * @author : kurisu
 * @version : 1.0
 * @className : StarSalaryCalculator
 * @description : 星级薪资计算器
 * @date : 2022-04-27 10:33
 */
@Component
@Slf4j
public class StarSalaryCalculator extends SalaryBaseCalculator {

    private final KpiPoolService kpiPoolService;
    private final KpiPoolCommonService kpiPoolCommonService;

    @Autowired
    public StarSalaryCalculator(final KpiPoolService kpiPoolService,
                                final KpiPoolCommonService kpiPoolCommonService) {
        this.kpiPoolService = kpiPoolService;
        this.kpiPoolCommonService = kpiPoolCommonService;
    }

    @Override
    public SalaryCalMethodEnum getCalMethod() {
        return SalaryCalMethodEnum.STAR;
    }

    @Override
    public BigDecimal calculate(SalaryGroupProject param1, SalaryGroupUser param2) {
        if (Boolean.TRUE.equals(param2.getProbationer())) {
            return null;
        }
        BigDecimal salaryValue = BigDecimal.ZERO;
        List<SalaryGroupProjectSettin> settins = queryProjectSettins(param1.getId());
        if (CollectionUtils.isEmpty(settins)) {
            return salaryValue;
        }
        KpiPool kpiPool = kpiPoolCommonService.queryPool(param2);
        BV.notNull(kpiPool, () -> MessageFormatUtil.MessageFormatTransfer("用户[{0}]的绩效数据不存在", param2.getUserId()));
        Optional<JSONObject> projectValue = queryRawDataValue(param2.getUserId(), param2.getDataDate(), param1.getSalaryProjectCode(), SalaryValueTypeEnum.RATIO);
        if (! projectValue.isPresent()) {
            return BigDecimal.ZERO;
        }

        StarLevelEnum starLevel = kpiPool.getActualStar();
        if (Objects.isNull(starLevel)) {
            return salaryValue;
        }
        for (SalaryGroupProjectSettin settin : settins) {
            if (Long.valueOf(starLevel.getValue().longValue()).equals(settin.getStairKey())) {
                BigDecimal stairValue = Optional.ofNullable(settin.getStairValue()).orElse(BigDecimal.ZERO);
                BigDecimal value = Optional.ofNullable(projectValue.get().getBigDecimal(param1.getSalaryProjectCode())).orElse(BigDecimal.ZERO);
                salaryValue = stairValue.multiply(value).divide(BigDecimal.ONE, 2, RoundingMode.HALF_UP);
                saveHitLog(param1.getSalaryProjectId(), settin.getId(), value, param2);
                break;
            }
        }
        return salaryValue;
    }
}
