package cn.fw.morax.service.biz.kpi;

import cn.fw.morax.common.utils.PublicUtil;
import cn.fw.morax.domain.db.kpi.Indicators;
import cn.fw.morax.domain.db.kpi.KpiGroup;
import cn.fw.morax.domain.db.kpi.KpiGroupIndicator;
import cn.fw.morax.domain.db.kpi.KpiGroupIndicatorLadders;
import cn.fw.morax.domain.enums.SettingStatusEnum;
import cn.fw.morax.domain.vo.kpi.KpiGroupIndicatorLaddersVO;
import cn.fw.morax.domain.vo.kpi.KpiGroupIndicatorVO;
import cn.fw.morax.service.data.kpi.KpiGroupIndicatorLaddersService;
import cn.fw.morax.service.data.kpi.KpiGroupIndicatorService;
import cn.fw.morax.service.data.kpi.KpiGroupService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.google.common.collect.Lists;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import static cn.fw.common.businessvalidator.Validator.BV;

@RequiredArgsConstructor
@Service
@Slf4j
public class KpiGroupIndicatorBizService {

    private final KpiGroupIndicatorLaddersService kpiGroupIndicatorLaddersService;
    private final KpiGroupIndicatorService kpiGroupIndicatorService;
    private final KpiGroupService kpiGroupService;

    /**
     * 绩效组指标详情
     *
     * @param kpiIndicatorId
     * @return
     */
    public KpiGroupIndicatorVO kpiGroupIndicatorDetail(Long kpiIndicatorId) {
        KpiGroupIndicator kpiGroupIndicator = kpiGroupIndicatorService.getById(kpiIndicatorId);
        BV.isNull(kpiGroupIndicator, "绩效指标配置不存在，请重试");
        KpiGroupIndicatorVO kpiGroupIndicatorVo = PublicUtil.copy(kpiGroupIndicator, KpiGroupIndicatorVO.class);

        List<KpiGroupIndicatorLadders> kpiGroupIndicatorLadders = kpiGroupIndicatorLaddersService.list(Wrappers.<KpiGroupIndicatorLadders>lambdaQuery()
                .eq(KpiGroupIndicatorLadders::getKpiGroupIndicatorId, kpiIndicatorId)
                .eq(KpiGroupIndicatorLadders::getYn, Boolean.TRUE)
        );
        if (PublicUtil.isNotEmpty(kpiGroupIndicatorLadders)) {
            List<KpiGroupIndicatorLaddersVO> indicatorLaddersVos = PublicUtil.copyList(kpiGroupIndicatorLadders, KpiGroupIndicatorLaddersVO.class);
            kpiGroupIndicatorVo.setIndicatorLadders(indicatorLaddersVos);
        }
        return kpiGroupIndicatorVo;
    }

    /**
     * 获取正在使用指标的绩效组
     *
     * @param indicatorId
     * @return
     */
    public List<KpiGroup> getKpiGroupByIndicatorId(Long indicatorId) {
        List<KpiGroupIndicator> kpiGroupIndicators = kpiGroupIndicatorService.list(Wrappers.<KpiGroupIndicator>lambdaQuery()
                .eq(KpiGroupIndicator::getIndicatorId, indicatorId)
        );
        if (PublicUtil.isEmpty(kpiGroupIndicators)) {
            return Lists.newArrayList();
        }
        List<SettingStatusEnum> status = new ArrayList<SettingStatusEnum>(){{
//            add(SettingStatusEnum.APPROVING);
//            add(SettingStatusEnum.BE_EFFECTIVE);
            add(SettingStatusEnum.EFFECTIVE);
        }};
        List<Long> kpiGroupIds = kpiGroupIndicators.stream().map(KpiGroupIndicator::getKpiGroupId).collect(Collectors.toList());
        List<KpiGroup> kpiGroups = kpiGroupService.list(Wrappers.<KpiGroup>lambdaQuery()
                .in(KpiGroup::getId, kpiGroupIds)
                .in(KpiGroup::getStatus, status)
                .eq(KpiGroup::getYn, Boolean.TRUE)
        );
        if (PublicUtil.isEmpty(kpiGroups)) {
            return Lists.newArrayList();
        }

        return kpiGroups;
    }

}
