package cn.fw.morax.service.data.kpi.impl;

import cn.fw.morax.dao.kpi.IndicatorsDao;
import cn.fw.morax.domain.db.kpi.Indicators;
import cn.fw.morax.domain.dto.query.IndicatorPostQueryDTO;
import cn.fw.morax.domain.dto.query.IndicatorQueryDTO;
import cn.fw.morax.domain.vo.kpi.IndicatorsVO;
import cn.fw.morax.service.data.kpi.IndicatorsService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.lang.NonNull;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author kurisu
 */
@Service
@Slf4j
@AllArgsConstructor
public class IndicatorsServiceImpl extends ServiceImpl<IndicatorsDao, Indicators> implements IndicatorsService {

    private final IndicatorsDao indicatorsDao;

    /**
     * 指标分页查询接口
     *
     * @param dto
     * @return
     */
    @Override
    public Long indicatorsPageTotal(IndicatorQueryDTO dto) {

        return indicatorsDao.selectPageTotal(dto);
    }

    /**
     * 指标分页查询接口
     *
     * @param dto
     * @return
     */
    @Override
    public List<IndicatorsVO> indicatorsPage(IndicatorQueryDTO dto) {

        return indicatorsDao.selectPageVo(dto);
    }

    @Override
    public Indicators queryByCode(@NonNull final String indicatorCode, final Boolean checkEffective) {
        return getOne(Wrappers.<Indicators>lambdaQuery()
                        .eq(Indicators::getIndicatorCode, indicatorCode)
                        .eq(Boolean.TRUE.equals(checkEffective), Indicators::getEnable, Boolean.TRUE)
                        .eq(Indicators::getYn, Boolean.TRUE)
                , false);
    }

    @Override
    public List<IndicatorsVO> getPostIndicators(IndicatorPostQueryDTO dto) {
        return this.getBaseMapper().getPostIndicators(dto);
    }
}
