package cn.fw.morax.service.data.salary;

import cn.fw.morax.domain.db.salary.SalaryGroup;
import cn.fw.morax.domain.dto.query.SalaryGroupRepeatQueryDTO;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.lang.NonNull;
import org.springframework.lang.Nullable;

import java.time.LocalDate;
import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * @author : kurisu
 * @className : SalaryGroupService
 * @description : 薪酬组配置
 * @date: 2022-04-06 17:05
 */
public interface SalaryGroupService extends IService<SalaryGroup> {

    /**
     * 查询重复的薪酬组配置，以集团、门店、岗位维度
     * 1. 当月重复数据
     * 1）查询已生效数据   条件：状态
     * 2）查询未生效数据   条件：状态、时间（时间>=其他配置生效时间）
     * 2. 次月之后重复数据
     * 1）查询次月之后未生效数据   条件：状态、时间（时间>=其他配置生效时间）
     *
     * @param dto
     */
    List<SalaryGroup> queryRepeatSalaryGroup(SalaryGroupRepeatQueryDTO dto);


    /**
     * 查询指定日期生效中的的薪酬组id集合
     *
     * @param localDate 日期
     * @return
     */
    @Nullable
    Set<Long> querySalaryGroupIdByDay(@NonNull final LocalDate localDate);

    /**
     * 根据指标编码和岗位码查询集团绩效组指标项
     *
     * @param salaryCode    指标编码
     * @param postId        岗位id
     * @param groupId       集团id
     * @param dataDate      数据日期
     * @return
     */
    List<Long> querySalaryGroupIdsByCode(final String salaryCode, final Long postId, final Long groupId, final Date dataDate);

    /**
     * 获取所有生效中薪酬组数据
     *
     * @param date
     * @return
     */
    List<SalaryGroup> getAllEffectGroups(Date date);

    /**
     * 门店岗位重复的薪酬组
     *
     * @param postId
     * @param shopIds
     * @param preId
     * @param beginTime
     * @return
     */
    List<SalaryGroup> getApprovingConfigs(Long postId, List<Long> shopIds, Long preId, LocalDate beginTime);
}
