package cn.fw.morax.service.data.salary.impl;

import cn.fw.morax.common.utils.PublicUtil;
import cn.fw.morax.dao.salary.SalaryProjectHitLogDao;
import cn.fw.morax.domain.db.salary.SalaryProjectHitLog;
import cn.fw.morax.service.data.salary.SalaryProjectHitLogService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.util.List;
import java.util.Objects;

/**
 * 用户薪酬命中记录
 *
 * @author : kurisu
 * @version : 1.0
 * @className : SalaryProjectHitLogServiceImpl
 * @description : 用户薪酬命中记录
 * @date : 2022-05-19 10:52
 */
@Service
public class SalaryProjectHitLogServiceImpl extends ServiceImpl<SalaryProjectHitLogDao, SalaryProjectHitLog> implements SalaryProjectHitLogService {
    @Override
    public void saveUnique(SalaryProjectHitLog salaryProjectHitLog) {
        Long salaryPoolId = salaryProjectHitLog.getSalaryPoolId();
        Long salaryProjectId = salaryProjectHitLog.getSalaryProjectId();
        LocalDate dataDate = salaryProjectHitLog.getDataDate();
        SalaryProjectHitLog hitLog = this.getOne(Wrappers.<SalaryProjectHitLog>lambdaQuery()
                .eq(SalaryProjectHitLog::getSalaryPoolId, salaryPoolId)
                .eq(SalaryProjectHitLog::getSalaryProjectId, salaryProjectId)
                .eq(SalaryProjectHitLog::getDataDate, dataDate)
                .eq(PublicUtil.isNotEmpty(salaryProjectHitLog.getSalaryGroupProjectSettinId()),
                        SalaryProjectHitLog::getSalaryGroupProjectSettinId, salaryProjectHitLog.getSalaryGroupProjectSettinId())
                .eq(SalaryProjectHitLog::getYn, Boolean.TRUE)
        );
        if (Objects.nonNull(hitLog)) {
            salaryProjectHitLog.setId(hitLog.getId());
        }
        this.saveOrUpdate(salaryProjectHitLog);
    }

    @Override
    public List<SalaryProjectHitLog> queryByProjectIds(Long salaryPoolId, List<Long> salaryProjectIds, LocalDate dataDate) {
        return this.list(Wrappers.<SalaryProjectHitLog>lambdaQuery()
                .eq(SalaryProjectHitLog::getSalaryPoolId, salaryPoolId)
                .in(SalaryProjectHitLog::getSalaryProjectId, salaryProjectIds)
                .eq(SalaryProjectHitLog::getYn, Boolean.TRUE)
                .eq(SalaryProjectHitLog::getDataDate, dataDate)
        );
    }
}
